| CBDQCS | R Documentation |
Fits and forecasts mortality rates using CBD with curvature and cohort model.
CBDQCS(
x,
M,
curve = c("gompertz", "makeham", "perks", "weibull", "beard", "martinelle", "thatcher",
"gompertz2", "makeham2", "perks2", "weibull2", "beard2", "martinelle2", "thatcher2"),
h = 10,
jumpoff = 1
)
x |
vector of ages. |
M |
matrix of mortality rates (rows as years and columns as ages). |
curve |
name of mortality curve for smoothing forecasted mortality rates (including gompertz, makeham, perks, weibull, beard, martinelle, thatcher, gompertz2, makeham2, perks2, weibull2, beard2, martinelle2, thatcher2, where first 7 curves' parameters are unconstrained and last 7 curves' parameters are generally restricted to be positive). |
h |
forecast horizon (default = 10). |
jumpoff |
if 1, forecasts are based on estimated parameters only; if 2, forecasts are anchored to observed mortality rates in final year (default = 1). |
The CBD with curvature and cohort (M7) model is specified as
ln(m_{x,t}) = \kappa_{1,t} + \kappa_{2,t} (x-\bar{x}) + \kappa_{3,t} ((x-\bar{x})^2-\sigma^2) + \gamma_{t-x} + \epsilon_{x,t}.
The model is estimated by Newton updating scheme and is forecasted by ARIMA applied to \kappa_{1,t}, \kappa_{2,t}, \kappa_{3,t}, and \gamma_c. Constraints include sum of \gamma_c is zero, sum of c\gamma_c is zero, and sum of c^{2}\gamma_c is zero. It is designed for ages 50-90.
An object of class CBDQCS with associated S3 methods coef, forecast, plot, and residuals.
Cairns, A.J.G., Blake, D., Dowd, K., Coughlan, G.D., Epstein, D., Ong, A., and Balevich, I. (2009). A quantitative comparison of stochastic mortality models using data from England and Wales and the United States. North American Actuarial Journal, 13(1), 1-35.
x <- 60:89
k1 <- -2.97-0.0245*(0:29)
k2 <- 0.101+0.000345*(0:29)
set.seed(123)
M <- exp(matrix(k1,nrow=30,ncol=30,byrow=FALSE)+outer(k2,(x-mean(x)))+rnorm(900,0,0.035))
fit <- CBDQCS(x=x,M=M,curve="makeham",h=30,jumpoff=2)
coef(fit)
forecast::forecast(fit)
plot(fit)
residuals(fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.